@@ -295,6 +295,17 @@ class API:  # pylint: disable=too-many-instance-attributes
 
                     LOGGER.debug("Data received from /%s: %s", endpoint, data)
 
+                    if isinstance(data, str):
+                        # In some cases, the SimpliSafe API will return a quoted string
+                        # in its response body (e.g., "\"node not found\""), which is
+                        # technically valid JSON. Additionally, SimpliSafe sets that
+                        # response's Content-Type header to application/json (#smh).
+                        # Together, these factors will allow a non-true-JSON  payload to
+                        # escape the try/except above. So, if we get here, we use the
+                        # string value (with quotes removed) to raise an error:
+                        message = data.replace('"', "")
+                        data = {"error": message}
+
                     resp.raise_for_status()
                     return data
             except ClientError as err:
@@ -323,20 +334,21 @@ class API:  # pylint: disable=too-many-instance-attributes
                     raise InvalidCredentialsError("Invalid username/password") from None
 
                 LOGGER.warning(
-                    "Error while requesting /%s: %s (%s retries remaining)",
+                    "Error while requesting /%s: %s (attempt %s of %s)",
                     endpoint,
                     err,
-                    retries,
+                    retries + 1,
+                    DEFAULT_REQUEST_RETRIES,
                 )
                 retries += 1
                 await asyncio.sleep(self._request_retry_interval)
             finally:
                 if not use_running_session:
                     await session.close()
-        else:
-            raise RequestError(
-                f"Requesting /{endpoint} failed after {retries} tries"
-            ) from None
+
+        raise RequestError(
+            f"Requesting /{endpoint} failed after {retries + 1} tries"
+        ) from None
 
     async def refresh_access_token(self, refresh_token: Optional[str]) -> None:
         """Regenerate an access token.
